import logger from '../../../utils/logger'
import utils from '../../../utils/utils'
import { Request, SubmoduleData, User } from '../../../types/basicTypes'

const msgFile = 'stats/msgs'
const uloadFiles = 'data/f'

function setup(data: SubmoduleData): void {
  const { app /* userDB, url, publicdirs, moduleSpecificData */ } = data

  app.post('/postfeedbackfile', function (req: Request, res: any) {
    utils
      .uploadFile(req, uloadFiles)
      .then(() => {
        res.json({ success: true })
      })
      .catch(() => {
        res.json({ success: false, msg: 'error during uploading' })
        return
      })

    logger.LogReq(req)
    logger.Log('New feedback file', logger.GetColor('bluebg'))
  })

  app.post('/postfeedback', function (req: Request, res: any) {
    logger.LogReq(req)
    if (req.body.fromLogin) {
      logger.Log(
        'New feedback message from Login page',
        logger.GetColor('bluebg')
      )
    } else {
      logger.Log(
        'New feedback message from feedback page',
        logger.GetColor('bluebg')
      )
    }

    const user: User = req.session.user

    utils.AppendToFile(
      utils.GetDateString() +
        ':\n' +
        JSON.stringify(
          {
            ...req.body,
            userID: user ? user.id : 'no user',
          },
          null,
          2
        ),
      msgFile
    )
    res.json({ success: true })
  })

  app.route('/fosuploader').post(function (req: Request, res: any) {
    utils.uploadFile(req, uloadFiles).then(({ fileName }) => {
      res.redirect('/f/' + fileName)
    })
  })
}

export default {
  setup: setup,
}
